--- old/usr/src/uts/common/fs/sockfs/sockcommon_sops.c	2015-08-09 12:47:42.604824739 +0300
+++ new/usr/src/uts/common/fs/sockfs/sockcommon_sops.c	2015-08-09 12:47:42.663803039 +0300
@@ -37,6 +37,7 @@
 #include <sys/stropts.h>
 #include <sys/socket.h>
 #include <sys/socketvar.h>
+#include <sys/fcntl.h>
 
 #define	_SUN_TPI_VERSION	2
 #include <sys/tihdr.h>
@@ -357,6 +358,7 @@
 			socket_destroy(nso);
 		} else {
 			*nsop = nso;
+			sonode_insert_pid(nso, curproc);
 		}
 	}
 
@@ -1540,6 +1542,45 @@
 	VN_RELE(SOTOV(so));
 }
 
+conn_pid_node_list_hdr_t *
+so_get_sock_pid_list(sock_upper_handle_t sock_handle)
+{
+	int sz, n = 0;
+	pid_node_t			*pn;
+	conn_pid_node_t			*cpn;
+	conn_pid_node_list_hdr_t	*cph;
+	struct sonode 			*so = (struct sonode *)sock_handle;
+
+	mutex_enter(&so->so_pid_list_lock);
+
+	n = list_size(&so->so_pid_list);
+	sz = sizeof (conn_pid_node_list_hdr_t);
+	sz += (n > 1)?((n - 1) * sizeof (conn_pid_node_t)):0;
+	cph = kmem_zalloc(sz, KM_SLEEP);
+
+	cph->cph_magic = CONN_PID_NODE_LIST_HDR_MAGIC;
+	cph->cph_contents = CONN_PID_NODE_LIST_HDR_SOC;
+	cph->cph_pn_cnt = n;
+	cph->cph_tot_size = sz;
+	cph->cph_flags = 0;
+	cph->cph_optional1 = 0;
+	cph->cph_optional2 = 0;
+
+	if (cph->cph_pn_cnt > 0) {
+		cpn = cph->cph_cpns;
+		pn = list_head(&so->so_pid_list);
+		while (pn != NULL) {
+			PIDNODE2CONNPIDNODE(pn, cpn);
+			pn = list_next(&so->so_pid_list, pn);
+			cpn++;
+		}
+	}
+
+	mutex_exit(&so->so_pid_list_lock);
+
+	return (cph);
+}
+
 void
 so_zcopy_notify(sock_upper_handle_t sock_handle)
 {
@@ -1940,5 +1981,6 @@
 	so_signal_oob,
 	so_zcopy_notify,
 	so_set_error,
-	so_closed
+	so_closed,
+	so_get_sock_pid_list
 };
